@@ -30,7 +30,12 @@ def load_external_providers(registry: ProviderRegistry) -> None:
     for ep in entry_points(group="ttkbootstrap_icons.providers"):
         try:
             ProviderCls = ep.load()
-            registry.register_provider(ProviderCls.name, ProviderCls())
-        except Exception:
-            # Ignore bad entry points, but continue loading others
-            pass
+            provider_instance = ProviderCls()
+            registry.register_provider(provider_instance.name, provider_instance)
+        except Exception as exc:
+            # Print a lightweight warning to help debug bad entry points
+            try:
+                print(f"[ttkbootstrap-icons] Failed to load provider entry point '{ep.name}' -> {ep.value}: {exc}")
+            except Exception:
+                # Ensure failures here never break app startup
+                pass
